@@ -4,7 +4,8 @@ use 5.014000;
 use strict;
 use warnings;
 use parent qw/Plack::Component/;
-our $VERSION = '0.000_002';
+use re '/s';
+our $VERSION = '0.001';
 
 use File::Find qw/find/;
 use File::Path qw/remove_tree/;
@@ -56,7 +57,7 @@ sub makepkg {
 	my $dest = catfile $dir, 'pkg';
 	mkdir $dest;
 	@pkgs = grep { exists $self->{cfg}{pkgs}{$_} } @pkgs;
-	push @pkgs, split ',', ($self->{cfg}{pkgs}{$_}{deps} // '') for @pkgs;
+	push @pkgs, split /,/, ($self->{cfg}{pkgs}{$_}{deps} // '') for @pkgs;
 	@pkgs = uniq @pkgs;
 	addpkg $_, $dest for @pkgs;
 	write_file catfile ($dir, 'readme.txt'), $self->{cfg}{readme};
@@ -68,7 +69,7 @@ sub makepkg {
 		find sub { push @zip_files, $File::Find::name if -f }, $dest;
 	}
 	zip \@zip_files, catfile($dir, 'pkg.zip'), FilterName => sub { $_ = abs2rel $_, $dir }, -Level => 1;
-	open my $fh, '<', catfile $dir, 'pkg.zip';
+	open my $fh, '<', catfile $dir, 'pkg.zip' or return [500, ['Content-Type' => 'text/plain;charset=utf-8'], ['Error opening pkg.zip']]; ## no critic (RequireBriefOpen)
 	remove_tree $dir;
 	[200, ['Content-Type' => 'application/zip', 'Content-Disposition' => 'attachment; filename=pkg.zip'], $fh]
 }
@@ -83,15 +84,15 @@ sub makelist {
 		my $opt = HTML::Element->new('option', value => '');
 		$opt->push_content('None');
 		$sel->push_content($opt);
-		for my $pkg (sort { $a->{name} cmp $b->{name} } values $tree) {
-			my $opt = HTML::Element->new('option', value => $pkg->{pkg}, $pkg->{default} ? (selected => 'selected') : ());
-			$opt->push_content($pkg->{name});
-			$sel->push_content($opt);
+		for my $pkg (sort { $a->{name} cmp $b->{name} } @$tree) {
+			my $option = HTML::Element->new('option', value => $pkg->{pkg}, $pkg->{default} ? (selected => 'selected') : ());
+			$option->push_content($pkg->{name});
+			$sel->push_content($option);
 		}
 		$elem->push_content($sel);
 	} else {
 		my $ul = HTML::Element->new('ul');
-		for my $key ($self->{cfg}{sort}->(keys $tree)) {
+		for my $key ($self->{cfg}{sort}->(keys %$tree)) {
 			my $li = HTML::Element->new('li', class => "level$lvl");
 			$self->makelist($li, $tree->{$key}, $lvl + 1, $key);
 			$ul->push_content($li);
@@ -103,10 +104,10 @@ sub makelist {
 sub makeindex {
 	my ($self) = @_;
 	my ($pkgs, $tree) = ($self->{cfg}{pkgs}, {});
-	for (keys $pkgs) {
-		my $ref = DiveRef ($tree, split ',', $pkgs->{$_}{path});
+	for (keys %$pkgs) {
+		my $ref = DiveRef ($tree, split /,/, $pkgs->{$_}{path});
 		$$ref = [] unless ref $$ref eq 'ARRAY';
-		push $$ref, {pkg => $_, name => $pkgs->{$_}{name}, default => $pkgs->{$_}{default}};
+		push @{$$ref}, {pkg => $_, name => $pkgs->{$_}{name}, default => $pkgs->{$_}{default}};
 	}
 	my $html = HTML::TreeBuilder->new_from_file('index.html');
 	$self->makelist(scalar $html->look_down(id => 'list'), $tree, 1);
@@ -232,7 +233,7 @@ Example:
 
 =head1 TODO
 
-For 0.001:
+For 1.000:
 * Tests
 * More/Clearer documentation
 * Nicer user interface
@@ -243,7 +244,7 @@ Marius Gavrilescu, E<lt>marius@ieval.roE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014 by Marius Gavrilescu
+Copyright (C) 2014-2015 by Marius Gavrilescu
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.18.2 or,
